@@ -146,7 +146,6 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
         try(expr= {
           P = GENEAread::read.bin(binfile=filename,start=tint[blocknumber,1],
                                   end=tint[blocknumber,2],calibrate=TRUE,do.temp=TRUE,mmap.load=FALSE)
-          # on.exit(closeAllConnections())
           if (sf != P$freq) sf = P$freq
         },silent=TRUE)
         if (length(P) <= 2) {
@@ -166,8 +165,9 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
       if (length(P) == 0) { #if first block doens't read then probably corrupt
         if (blocknumber == 1) {
           #try to read without specifying blocks (file too short)
-          try(expr={P = GENEAread::read.bin(binfile=filename,start=1,end=10,calibrate=TRUE,do.temp=TRUE,mmap.load=FALSE)},silent=TRUE)
-          # on.exit(closeAllConnections())
+          try(expr={P = GENEAread::read.bin(binfile=filename,start=1,end=10,
+                                            calibrate=TRUE,do.temp=TRUE,
+                                            mmap.load=FALSE)},silent=TRUE)
           if (length(P) == 0) {
             warning('\nFile possibly corrupt\n')
             P= c(); switchoffLD = 1
@@ -196,12 +196,14 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
       startpage = UPI$startpage;    endpage = UPI$endpage
       try(expr={P = GENEAread::read.bin(binfile=filename,start=startpage,
                                         end=endpage,calibrate=TRUE,do.temp=TRUE,mmap.load=FALSE)},silent=TRUE)
-      # on.exit(closeAllConnections())
       if (length(P) <= 2) {
         #try again but now with mmap.load turned on
-        try(expr={P = GENEAread::read.bin(binfile=filename,start=startpage,
-                                          end=endpage,calibrate=TRUE,do.temp=TRUE,mmap.load=TRUE)},silent=TRUE)
-        # on.exit(closeAllConnections())
+        options(warn=-1) # to ignore warnings relating to failed mmap.load attempt
+        try(expr={
+          P = GENEAread::read.bin(binfile=filename,start=startpage,
+                                          end=endpage,calibrate=TRUE,do.temp=TRUE,mmap.load=TRUE)
+        },silent=TRUE)
+        options(warn=0) # to ignore GENEAread warnings
         if (length(P) != 0) {
           if (sf != P$freq) sf = P$freq
         } else {
@@ -218,8 +220,9 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
       if (length(P) == 0) { #if first block doens't read then probably corrupt
         if (blocknumber == 1) {
           #try to read without specifying blocks (file too short)
-          try(expr={P = GENEAread::read.bin(binfile=filename,calibrate=TRUE,do.temp=TRUE,mmap.load=FALSE)},silent=TRUE)
-          # on.exit(closeAllConnections())
+          try(expr={
+            P = GENEAread::read.bin(binfile=filename,calibrate=TRUE, do.temp=TRUE, mmap.load=FALSE)
+            },silent=TRUE)
           if (length(P) == 0) {
             warning('\nFile possibly corrupt\n')
             P= c(); switchoffLD = 1
@@ -471,8 +474,5 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
       P = c()
     }
   }
-  if ("gzfile" %in% showConnections(all = T)[,1] == TRUE) {
-    closeAllConnections()
-  }
   invisible(list(P=P,filequality=filequality, switchoffLD = switchoffLD, endpage = endpage,  startpage = startpage))
 }
