@@ -6,7 +6,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   if (length(input) > 0) {
     for (i in 1:length(names(input))) {
       txt = paste(names(input)[i],"=",input[i],sep="")
-      if (class(unlist(input[i])) == "character") {
+      if (class(unlist(input[i])) == "character" & length(unlist(input[i])) == 1) {
         txt = paste(names(input)[i],"='",unlist(input[i]),"'",sep="")
       }
       eval(parse(text=txt))
@@ -37,7 +37,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
     # if (length(which(mode == 0)) > 0) dopart0 = TRUE
     if (length(which(mode == 1)) > 0) dopart1 = TRUE
     if (length(which(mode == 2)) > 0) dopart2 = TRUE
-    if (length(which(mode == 3)) > 0) dopart3 = TRUE; do.anglez = TRUE
+    if (length(which(mode == 3)) > 0) { dopart3 = TRUE; do.anglez = TRUE }
     if (length(which(mode == 4)) > 0) dopart4 = TRUE
     if (length(which(mode == 5)) > 0) dopart5 = TRUE
   }
@@ -97,7 +97,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
           } else if (numi == TRUE) {
             txt = paste(as.character(config[ci,1]),"=",as.numeric(config[ci,2]),"",sep="")
           } else if (numi == FALSE & logi == FALSE) {
-            if (length(config[ci,2]) > 0) {
+            if (length(config[ci,2]) > 0 & !is.na(config[ci,2])) {
               if (config[ci,2] == 'c()') {
                 if (config[ci,1] == "def.no.sleep") def.no.sleep = c()
                 if (config[ci,1] == "backup.cal.coef") backup.cal.coef = c()
@@ -112,7 +112,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
                   if (isna == TRUE) { # it is a vector with characters
                     vecchar = unlist(strsplit(unlist(strsplit(config[ci,2],"\\(|\\)"))[2],","))
                     if (config[ci,1] == "timewindow") timewindow = vecchar
-                    
+
                   } else {
                     txt = paste(as.character(config[ci,1]),"=",config[ci,2],"",sep="")
                   }
@@ -128,13 +128,14 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
     }
   }
   # obtain default parameter values if not provided:
-  
+
   # GENERAL parameters:
   if (exists("overwrite") == FALSE)   overwrite = FALSE
   if (exists("acc.metric") == FALSE)  acc.metric = "ENMO"
   if (exists("storefolderstructure") == FALSE)  storefolderstructure = FALSE
   if (exists("myfun") == FALSE)  myfun = c()
-  
+  if (exists("maxNcores") == FALSE)  maxNcores = c()
+
   if (exists("ignorenonwear") == FALSE)  ignorenonwear = TRUE
   if (exists("print.filename") == FALSE)  print.filename = FALSE
   if (exists("do.parallel") == FALSE)  do.parallel = TRUE
@@ -185,11 +186,11 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   if (exists("idloc") == FALSE) idloc = 1
   if (exists("backup.cal.coef") == FALSE)  backup.cal.coef = "retrieve"
   if (exists("minimumFileSizeMB") == FALSE)  minimumFileSizeMB = 2
-  
+
   if (length(myfun) != 0) { # Run check on myfun object
     check_myfun(myfun, windowsizes)
   }
-  
+
   # PART 2
   if (exists("strategy") == FALSE)  strategy = 1
   if (exists("maxdur") == FALSE)  maxdur = 0
@@ -206,7 +207,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   if (exists("ndayswindow") == FALSE)  ndayswindow = 7
   if (exists("do.imp") == FALSE) do.imp = TRUE
   if (exists("IVIS_windowsize_minutes") == FALSE)  IVIS_windowsize_minutes=60
-  if (exists("IVIS_epochsize_seconds") == FALSE)  IVIS_epochsize_seconds=c()
+  if (exists("IVIS_epochsize_seconds") == FALSE)  IVIS_epochsize_seconds=NA
   if (exists("mvpadur") == FALSE)  mvpadur = c(1,5,10) # related to part 2 (functionality to anticipate part 5)
   if (length(mvpadur) != 3) {
     mvpadur = c(1,5,10)
@@ -216,18 +217,21 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   if (exists("window.summary.size") == FALSE) window.summary.size = 10
   if (exists("dayborder") == FALSE)  dayborder = 0
   if (exists("iglevels") == FALSE)  iglevels = c()
+  if (length(iglevels) > 0) {
+    if (length(iglevels) == 1) iglevels = c(seq(0,4000,by=25),8000) # to introduce option to just say TRUE
+  }
   if (exists("TimeSegments2ZeroFile") == FALSE) TimeSegments2ZeroFile = c()
   if (exists("IVIS.activity.metric") == FALSE)  IVIS.activity.metric = 2
   if (exists("qM5L5") == FALSE)  qM5L5 = c()
   if (exists("MX.ig.min.dur") == FALSE)  MX.ig.min.dur = 10
-  
-  
+
+
   # PART 3
   if (exists("anglethreshold") == FALSE)  anglethreshold = 5
   if (exists("timethreshold") == FALSE)  timethreshold = 5
   if (exists("constrain2range") == FALSE) constrain2range = TRUE
   if (exists("do.part3.pdf") == FALSE) do.part3.pdf = TRUE
-  
+
   # PART 4
   if (exists("loglocation") == FALSE)  loglocation = c()
   if (length(loglocation) == 1) {
@@ -252,7 +256,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   # PART 5
   if (exists("excludefirstlast.part5") == FALSE)  excludefirstlast.part5=FALSE
   if (exists("includenightcrit") == FALSE)  includenightcrit=16
-  if (exists("bout.metric") == FALSE)  bout.metric = 4 # changed on 13-04-2020, because it is what we have been recommending all the time
+  if (exists("bout.metric") == FALSE)  bout.metric = 6
   if (exists("closedbout") == FALSE)  closedbout = FALSE
   if (exists("boutcriter.in") == FALSE)  boutcriter.in = 0.9
   if (exists("boutcriter.lig") == FALSE)  boutcriter.lig = 0.8
@@ -269,43 +273,55 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   if (exists("save_ms5raw_without_invalid") == FALSE) save_ms5raw_without_invalid = TRUE
   if (exists("includedaycrit.part5") == FALSE) includedaycrit.part5 = 2/3
   if (exists("minimum_MM_length.part5") == FALSE) minimum_MM_length.part5 = 23
-  
+  if (exists("frag.metrics") == FALSE) frag.metrics = c()
+  if (exists("part5_agg2_60seconds") == FALSE) part5_agg2_60seconds = FALSE
+
   # Related to (r)ead (m)yacc (c)sv file:
-  if (length(which(ls() == "rmc.dec")) == 0) rmc.dec="."
-  if (length(which(ls() == "rmc.firstrow.acc")) == 0) rmc.firstrow.acc = c()
-  if (length(which(ls() == "rmc.firstrow.header")) == 0) rmc.firstrow.header=c()
-  if (length(which(ls() == "rmc.header.length")) == 0)  rmc.header.length= c()
-  if (length(which(ls() == "rmc.col.acc")) == 0) rmc.col.acc = 1:3
-  if (length(which(ls() == "rmc.col.temp")) == 0) rmc.col.temp = c()
-  if (length(which(ls() == "rmc.col.time")) == 0) rmc.col.time=c()
-  if (length(which(ls() == "rmc.unit.acc")) == 0) rmc.unit.acc = "g"
-  if (length(which(ls() == "rmc.unit.temp")) == 0) rmc.unit.temp = "C"
-  if (length(which(ls() == "rmc.unit.time")) == 0) rmc.unit.time = "POSIX"
-  if (length(which(ls() == "rmc.format.time")) == 0) rmc.format.time = "%Y-%m-%d %H:%M:%OS"
-  if (length(which(ls() == "rmc.bitrate")) == 0) rmc.bitrate = c()
-  if (length(which(ls() == "rmc.dynamic_range")) == 0) rmc.dynamic_range = c()
-  if (length(which(ls() == "rmc.unsignedbit")) == 0) rmc.unsignedbit = TRUE
-  if (length(which(ls() == "rmc.origin")) == 0) rmc.origin = "1970-01-01"
-  if (length(which(ls() == "rmc.desiredtz")) == 0) rmc.desiredtz= ""
-  if (length(which(ls() == "rmc.sf")) == 0) rmc.sf  = c()
-  if (length(which(ls() == "rmc.headername.sf")) == 0) rmc.headername.sf = c()
-  if (length(which(ls() == "rmc.headername.sn")) == 0) rmc.headername.sn = c()
-  if (length(which(ls() == "rmc.headername.recordingid")) == 0) rmc.headername.recordingid = c()
-  if (length(which(ls() == "rmc.header.structure")) == 0) rmc.header.structure = c()
-  if (length(which(ls() == "rmc.check4timegaps")) == 0) rmc.check4timegaps = FALSE
-  if (length(which(ls() == "rmc.noise")) == 0) rmc.noise = FALSE
-  if (length(which(ls() == "rmc.col.wear")) == 0) rmc.col.wear = c()
-  if (length(which(ls() == "rmc.doresample")) == 0) rmc.doresample = FALSE
-  if (length(which(ls() == "part5_agg2_60seconds")) == 0) part5_agg2_60seconds = FALSE
-  
+  if (exists("rmc.dec") == FALSE) rmc.dec="."
+  if (exists("rmc.firstrow.acc") == FALSE) rmc.firstrow.acc = c()
+  if (exists("rmc.firstrow.header") == FALSE) rmc.firstrow.header=c()
+  if (exists("rmc.header.length") == FALSE) rmc.header.length= c()
+  if (exists("rmc.col.acc") == FALSE) rmc.col.acc = 1:3
+  if (exists("rmc.col.temp") == FALSE) rmc.col.temp = c()
+  if (exists("rmc.col.time") == FALSE) rmc.col.time=c()
+  if (exists("rmc.unit.acc") == FALSE) rmc.unit.acc = "g"
+  if (exists("rmc.unit.temp") == FALSE) rmc.unit.temp = "C"
+  if (exists("rmc.unit.time") == FALSE) rmc.unit.time = "POSIX"
+  if (exists("rmc.format.time") == FALSE) rmc.format.time = "%Y-%m-%d %H:%M:%OS"
+  if (exists("rmc.bitrate") == FALSE) rmc.bitrate = c()
+  if (exists("rmc.dynamic_range") == FALSE) rmc.dynamic_range = c()
+  if (exists("rmc.unsignedbit") == FALSE) rmc.unsignedbit = TRUE
+  if (exists("rmc.origin") == FALSE) rmc.origin = "1970-01-01"
+  if (exists("rmc.desiredtz") == FALSE) rmc.desiredtz= ""
+  if (exists("rmc.sf") == FALSE) rmc.sf  = c()
+  if (exists("rmc.headername.sf") == FALSE) rmc.headername.sf = c()
+  if (exists("rmc.headername.sn") == FALSE) rmc.headername.sn = c()
+  if (exists("rmc.headername.recordingid") == FALSE) rmc.headername.recordingid = c()
+  if (exists("rmc.header.structure") == FALSE) rmc.header.structure = c()
+  if (exists("rmc.check4timegaps") == FALSE) rmc.check4timegaps = FALSE
+  if (exists("rmc.noise") == FALSE) rmc.noise = FALSE
+  if (exists("rmc.col.wear") == FALSE) rmc.col.wear = c()
+  if (exists("rmc.doresample") == FALSE) rmc.doresample = FALSE
+  if (exists("part5_agg2_60seconds") == FALSE) part5_agg2_60seconds = FALSE
+  if (exists("week_weekend_aggregate.part5") == FALSE) week_weekend_aggregate.part5=FALSE
+  if (exists("LUXthresholds") == FALSE) LUXthresholds = c(0, 100, 500, 1000, 3000, 5000, 10000)
+  if (exists("LUX_cal_constant") == FALSE) LUX_cal_constant = c()
+  if (exists("LUX_cal_exponent") == FALSE) LUX_cal_exponent = c()
+  if (exists("LUX_day_segments") == FALSE) LUX_day_segments = c()
   
+  if (length(LUX_day_segments) > 0) {
+    LUX_day_segments = sort(unique(round(LUX_day_segments)))
+    if (LUX_day_segments[1] != 0) LUX_day_segments = c(0, LUX_day_segments)
+    if (LUX_day_segments[length(LUX_day_segments)] != 24) LUX_day_segments = c(LUX_day_segments, 24)
+    
+  }
   # VISUAL REPORT
-  
+
   if (exists("viewingwindow") == FALSE)  viewingwindow = 1
   if (exists("dofirstpage") == FALSE)  dofirstpage = TRUE
   if (exists("visualreport") == FALSE)  visualreport = FALSE
-  
-  
+
+
   GGIRversion = ""
   SI = sessionInfo()
   try(expr = {GGIRversion = SI$loadedOnly$GGIR$Version},silent=TRUE)
@@ -314,11 +330,12 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   }
   if (length(GGIRversion) == 0) GGIRversion = "could not extract version"
   GGIRversion = paste0(" ",GGIRversion)
+  rm(SI)
   cat(paste0("\n   GGIR version: ",GGIRversion,"\n"))
   cat("\n   Do not forget to cite GGIR in your publications via a version number and\n")
   cat("   Migueles et al. 2019 JMPB. doi: 10.1123/jmpb.2018-0063. \n")
   cat("   See also: https://cran.r-project.org/package=GGIR/vignettes/GGIR.html#citing-ggir \n")
-  
+
   if (dopart1 == TRUE) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
@@ -339,7 +356,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
             do.dev_roll_med_acc_y=do.dev_roll_med_acc_y,
             do.dev_roll_med_acc_z=do.dev_roll_med_acc_z,
             do.enmoa = do.enmoa,
-            do.lfx=do.lfx, do.lfy=do.lfy, do.lfz=do.lfz, 
+            do.lfx=do.lfx, do.lfy=do.lfy, do.lfz=do.lfz,
             do.hfx=do.hfx, do.hfy=do.hfy, do.hfz=do.hfz,
             do.bfx=do.bfx, do.bfy=do.bfy, do.bfz=do.bfz,
             do.sgAccEN=do.sgAccEN, do.sgAnglex=do.sgAnglex,
@@ -370,7 +387,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
             rmc.check4timegaps = rmc.check4timegaps, rmc.noise=rmc.noise,
             rmc.col.wear=rmc.col.wear,
             rmc.doresample=rmc.doresample,
-            myfun=myfun)
+            myfun=myfun, maxNcores=maxNcores)
   }
   if (dopart2 == TRUE) {
     cat('\n')
@@ -390,7 +407,8 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
             IVIS_windowsize_minutes = IVIS_windowsize_minutes,
             IVIS_epochsize_seconds = IVIS_epochsize_seconds, iglevels = iglevels,
             IVIS.activity.metric=IVIS.activity.metric, TimeSegments2ZeroFile = TimeSegments2ZeroFile,
-            qM5L5=qM5L5, do.parallel = do.parallel, myfun=myfun, MX.ig.min.dur=MX.ig.min.dur)
+            qM5L5=qM5L5, do.parallel = do.parallel, myfun=myfun, MX.ig.min.dur=MX.ig.min.dur,
+            maxNcores=maxNcores)
   }
   if (dopart3 == TRUE) {
     cat('\n')
@@ -400,8 +418,8 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
     g.part3(metadatadir=metadatadir,f0=f0, acc.metric = acc.metric,
             f1=f1,anglethreshold=anglethreshold,timethreshold=timethreshold,
             ignorenonwear=ignorenonwear,overwrite=overwrite,desiredtz=desiredtz,
-            constrain2range=constrain2range, do.parallel = do.parallel, dayborder=dayborder,
-            myfun=myfun)
+            constrain2range=constrain2range, do.parallel = do.parallel,
+            myfun=myfun, maxNcores=maxNcores)
   }
   if (dopart4 == TRUE) {
     cat('\n')
@@ -436,12 +454,17 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
             boutdur.in = boutdur.in,
             boutdur.lig = boutdur.lig,
             winhr = winhr,M5L5res = M5L5res,
-            overwrite=overwrite,desiredtz=desiredtz,dayborder=dayborder,
+            overwrite=overwrite,desiredtz=desiredtz, bout.metric=bout.metric,dayborder=dayborder,
             save_ms5rawlevels = save_ms5rawlevels, do.parallel = do.parallel,
             part5_agg2_60seconds=part5_agg2_60seconds, save_ms5raw_format=save_ms5raw_format,
             save_ms5raw_without_invalid=save_ms5raw_without_invalid,
+            # frag.classes.day = frag.classes.day, frag.classes.spt = frag.classes.spt,
+            frag.metrics = frag.metrics,
             data_cleaning_file=data_cleaning_file,
-            includedaycrit.part5=includedaycrit.part5)
+            includedaycrit.part5=includedaycrit.part5, iglevels=iglevels,
+            LUXthresholds=LUXthresholds, maxNcores=maxNcores,
+            LUX_cal_constant=LUX_cal_constant, LUX_cal_exponent=LUX_cal_exponent,
+            LUX_day_segments=LUX_day_segments)
   }
   #--------------------------------------------------
   # Store configuration parameters in config file
@@ -449,7 +472,7 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
   LS = LS[which(LS %in% c("input", "txt", "derivef0f1", "dopart1", "dopart2", "dopart3", "LS",
                           "dopart4", "dopart5", "fnames", "useRDA", "metadatadir", "ci", "config",
                           "configfile", "filelist", "outputfoldername", "numi", "logi",
-                          "conv2logical", "conv2num") == FALSE)]
+                          "conv2logical", "conv2num", "SI") == FALSE)]
   config.parameters = mget(LS) #lapply(mget(ls()), is.data.frame)
   config.matrix = createConfigFile(config.parameters)
   if (dir.exists(metadatadir)) {
@@ -505,11 +528,13 @@ g.shell.GGIR = function(mode=1:5,datadir=c(),outputdir=c(),studyname=c(),f0=1,f1
     if (N.files.ms5.out < f0) f0 = 1
     if (N.files.ms5.out < f1) f1 = N.files.ms5.out
     if (f1 == 0) f1 = N.files.ms5.out
-    
+
     g.report.part5(metadatadir=metadatadir,f0=f0,f1=f1,loglocation=loglocation,
                    includenightcrit=includenightcrit,includedaycrit=includedaycrit,
                    data_cleaning_file=data_cleaning_file, includedaycrit.part5=includedaycrit.part5,
-                   minimum_MM_length.part5=minimum_MM_length.part5)
+                   minimum_MM_length.part5=minimum_MM_length.part5,
+                   week_weekend_aggregate.part5=week_weekend_aggregate.part5,
+                   LUX_day_segments=LUX_day_segments)
   }
   if (visualreport == TRUE) {
     cat('\n')
