@@ -12,22 +12,25 @@ identify_levels = function(ts,
   LEVELS[ts$sibdetection == 1 & ts$diur == 1] = 0 #Sleep during the Sleep Period Time Window
   LEVELS[ts$sibdetection == 0 & ts$diur == 1] = 1 #Wakefullness during Sleep Period Time Window
   # activity during the night
-  LEVELS[ts$sibdetection == 0 & ts$diur == 1 & ts$ACC > TRLi & ts$ACC <= TRMi] = 2 #LIGHT
-  LEVELS[ts$sibdetection == 0 & ts$diur == 1 & ts$ACC > TRMi & ts$ACC <= TRVi] = 3 #MODERATE
-  LEVELS[ts$sibdetection == 0 & ts$diur == 1 & ts$ACC > TRVi] = 4 #VIGOROUS
+  LEVELS[ts$sibdetection == 0 & ts$diur == 1 & ts$ACC >= TRLi & ts$ACC < TRMi] = 2 #LIGHT
+  LEVELS[ts$sibdetection == 0 & ts$diur == 1 & ts$ACC >= TRMi & ts$ACC < TRVi] = 3 #MODERATE
+  LEVELS[ts$sibdetection == 0 & ts$diur == 1 & ts$ACC >= TRVi] = 4 #VIGOROUS
   Lnames = c("spt_sleep","spt_wake_IN", "spt_wake_LIG", "spt_wake_MOD", "spt_wake_VIG")
   # activity during the day
   #======================================
-  LEVELS[ts$diur == 0 & ts$ACC <= TRLi] = 5 # Inactivit
-  LEVELS[ts$diur == 0 & ts$ACC > TRLi & ts$ACC <= TRMi] = 6 #LIGHT
-  LEVELS[ts$diur == 0 & ts$ACC > TRMi & ts$ACC <= TRVi] = 7 #MODERATE
-  LEVELS[ts$diur == 0 & ts$ACC > TRVi] = 8 #VIGOROUS
+  LEVELS[ts$diur == 0 & ts$ACC < TRLi] = 5 # Inactivit
+  LEVELS[ts$diur == 0 & ts$ACC >= TRLi & ts$ACC < TRMi] = 6 #LIGHT
+  LEVELS[ts$diur == 0 & ts$ACC >= TRMi & ts$ACC < TRVi] = 7 #MODERATE
+  LEVELS[ts$diur == 0 & ts$ACC >= TRVi] = 8 #VIGOROUS
   Lnames = c(Lnames,"day_IN_unbt", "day_LIG_unbt", "day_MOD_unbt","day_VIG_unbt")
   # store separate copy of moderate and vigorous levels
+  # note that when OLEVELS equal zero this is sleep period time window
   OLEVELS[LEVELS == 5] = 1 #IN
   OLEVELS[LEVELS == 6] = 2 #LIGHT
   OLEVELS[LEVELS == 7] = 3 #MOD
   OLEVELS[LEVELS == 8] = 4 #VIG
+  
+
   #-------------------------------------
   # MVPA BOUTS
   LN = length(ts$time)
@@ -59,19 +62,18 @@ identify_levels = function(ts,
   NBL = length(boutduration) #number of bout lengths
   bc.in = c()
   for (BL in 1:NBL) {
-    rr1 = rep(0,LN)
-    p = which((ts$ACC < TRLi) & refe == 0 & ts$diur == 0); rr1[p] = 1
-    out1 = g.getbout(x=rr1,boutduration=boutduration[BL],boutcriter=boutcriter.in,
-                     closedbout=FALSE,bout.metric=bout.metric,ws3=ws3)
+    rr1 = rep(0, LN)
+    p = which(ts$ACC < TRLi & refe == 0 & ts$diur == 0); rr1[p] = 1
+    out1 = g.getbout(x=rr1, boutduration=boutduration[BL], boutcriter=boutcriter.in,
+                     closedbout=FALSE, bout.metric=bout.metric, ws3=ws3)
     LEVELS[ts$diur == 0 & out1$x == 1] = CL
-    bc.in = rbind(bc.in,out1$boutcount)
+    bc.in = rbind(bc.in, out1$boutcount)
     refe = refe + out1$x
     if (BL == 1) {
-      Lnames = c(Lnames,paste0("day_IN_bts_",boutdur.in[BL]))
+      Lnames = c(Lnames,paste0("day_IN_bts_", boutdur.in[BL]))
     } else {
-      Lnames = c(Lnames,paste0("day_IN_bts_",boutdur.in[BL],"_",boutdur.in[BL-1]))
+      Lnames = c(Lnames,paste0("day_IN_bts_", boutdur.in[BL], "_", boutdur.in[BL-1]))
     }
-    
     CL = CL + 1
   }
   #-------------------------------------
