@@ -19,7 +19,7 @@ test_that("Part 1 can run with all metrics", {
           do.enmo = TRUE,do.lfenmo = TRUE,
           do.bfen = TRUE,
           do.hfenplus = TRUE,
-          do.mad = TRUE,
+          do.mad = TRUE, do.sgAccEN=FALSE,
    windowsizes = c(15,3600,3600), do.parallel=FALSE,
    minimumFileSizeMB=0)
   rn = dir("output_test/meta/basic/",full.names = TRUE)
